@@ -20,14 +20,13 @@
 
 package App::MtAws::SingleDownloadJob;
 
-our $VERSION = '0.974_01';
+our $VERSION = '0.974_02';
 
 use strict;
 use warnings;
 use utf8;
 use base qw/App::MtAws::Job/;
 use App::MtAws::Utils;
-use File::stat;
 use Carp;
 
 
@@ -63,7 +62,6 @@ sub finish_task
 	my ($self, $task) = @_;
 	if ($self->{raised}) {
 		my $mtime = $task->{data}{mtime};
-		utime $mtime, $mtime, binaryfilename($task->{data}{filename}) or confess if defined $mtime;
 		return ("done");
 	} else {
 		confess;
